@@ -3,51 +3,50 @@ from enum import Enum
 
 
 class IntervalLevel(Enum):
-    """
+    """ """
 
-    """
-    LEVEL_TICK = 'tick'
-    LEVEL_1MIN = '1m'
-    LEVEL_5MIN = '5m'
-    LEVEL_15MIN = '15m'
-    LEVEL_30MIN = '30m'
-    LEVEL_1HOUR = '1h'
-    LEVEL_4HOUR = '4h'
-    LEVEL_1DAY = '1d'
-    LEVEL_1WEEK = '1wk'
-    LEVEL_1MON = '1mon'
+    LEVEL_TICK = "tick"
+    LEVEL_1MIN = "1m"
+    LEVEL_5MIN = "5m"
+    LEVEL_15MIN = "15m"
+    LEVEL_30MIN = "30m"
+    LEVEL_1HOUR = "1h"
+    LEVEL_4HOUR = "4h"
+    LEVEL_1DAY = "1d"
+    LEVEL_1WEEK = "1wk"
+    LEVEL_1MON = "1mon"
 
     def to_pd_freq(self):
         if self == IntervalLevel.LEVEL_1MIN:
-            return '1min'
+            return "1min"
         if self == IntervalLevel.LEVEL_5MIN:
-            return '5min'
+            return "5min"
         if self == IntervalLevel.LEVEL_15MIN:
-            return '15min'
+            return "15min"
         if self == IntervalLevel.LEVEL_30MIN:
-            return '30min'
+            return "30min"
         if self == IntervalLevel.LEVEL_1HOUR:
-            return '1H'
+            return "1H"
         if self == IntervalLevel.LEVEL_4HOUR:
-            return '4H'
+            return "4H"
         if self >= IntervalLevel.LEVEL_1DAY:
-            return '1D'
+            return "1D"
 
     def floor_timestamp(self, pd_timestamp):
         if self == IntervalLevel.LEVEL_1MIN:
-            return pd_timestamp.floor('1min')
+            return pd_timestamp.floor("1min")
         if self == IntervalLevel.LEVEL_5MIN:
-            return pd_timestamp.floor('5min')
+            return pd_timestamp.floor("5min")
         if self == IntervalLevel.LEVEL_15MIN:
-            return pd_timestamp.floor('15min')
+            return pd_timestamp.floor("15min")
         if self == IntervalLevel.LEVEL_30MIN:
-            return pd_timestamp.floor('30min')
+            return pd_timestamp.floor("30min")
         if self == IntervalLevel.LEVEL_1HOUR:
-            return pd_timestamp.floor('1h')
+            return pd_timestamp.floor("1h")
         if self == IntervalLevel.LEVEL_4HOUR:
-            return pd_timestamp.floor('4h')
+            return pd_timestamp.floor("4h")
         if self == IntervalLevel.LEVEL_1DAY:
-            return pd_timestamp.floor('1d')
+            return pd_timestamp.floor("1d")
 
     def to_minute(self):
         return int(self.to_second() / 60)
@@ -103,91 +102,89 @@ class IntervalLevel(Enum):
 class AdjustType(Enum):
     # 这里用拼音，因为英文不直观 split-adjusted？wtf?
     # 不复权
-    bfq = 'bfq'
+    bfq = "bfq"
     # 前复权
-    qfq = 'qfq'
+    qfq = "qfq"
     # 后复权
-    hfq = 'hfq'
+    hfq = "hfq"
 
 
 class ActorType(Enum):
     # 个人
-    individual = 'individual'
+    individual = "individual"
     # 公募基金
-    raised_fund = 'raised_fund'
+    raised_fund = "raised_fund"
     # 社保
-    social_security = 'social_security'
+    social_security = "social_security"
     # 保险
-    insurance = 'insurance'
+    insurance = "insurance"
     # 外资
-    qfii = 'qfii'
+    qfii = "qfii"
     # 信托
-    trust = 'trust'
+    trust = "trust"
     # 券商
-    broker = 'broker'
+    broker = "broker"
     # 私募
-    private_equity = 'private_equity'
+    private_equity = "private_equity"
     # 公司(可能包括私募)
-    corporation = 'corporation'
+    corporation = "corporation"
 
 
 class TradableType(Enum):
     # A股(中国)
-    stock = 'stock'
+    stock = "stock"
     # 美股
-    stockus = 'stockus'
+    stockus = "stockus"
     # 港股
-    stockhk = 'stockhk'
+    stockhk = "stockhk"
     # 期货(中国)
-    future = 'future'
+    future = "future"
     # 数字货币
-    coin = 'coin'
+    coin = "coin"
     # 期权
-    option = 'option'
+    option = "option"
     # 基金
-    fund = 'fund'
+    fund = "fund"
 
 
 class Exchange(Enum):
     # 上证交易所
-    sh = 'sh'
+    sh = "sh"
     # 深证交易所
-    sz = 'sz'
+    sz = "sz"
 
     # 对于中国的非交易所的 标的
-    cn = 'cn'
+    cn = "cn"
 
     # 纳斯达克
-    nasdaq = 'nasdaq'
+    nasdaq = "nasdaq"
 
     # 纽交所
-    nyse = 'nyse'
+    nyse = "nyse"
 
     # 港交所
-    hk = 'hk'
+    hk = "hk"
 
     # 数字货币
-    binance = 'binance'
-    huobipro = 'huobipro'
+    binance = "binance"
+    huobipro = "huobipro"
 
     # 上海期货交易所
-    shfe = 'shfe'
+    shfe = "shfe"
     # 大连商品交易所
     dce = "dce"
     # 郑州商品交易所
-    czce = 'czce'
+    czce = "czce"
     # 中国金融期货交易所
-    cffex = 'cffex'
+    cffex = "cffex"
 
 
 tradable_type_map_exchanges = {
     TradableType.stock: [Exchange.sh, Exchange.sz],
     TradableType.stockhk: [Exchange.hk],
     TradableType.stockus: [Exchange.nasdaq, Exchange.nyse],
-
     TradableType.future: [Exchange.shfe, Exchange.dce, Exchange.czce, Exchange.cffex],
-
-    TradableType.coin: [Exchange.binance, Exchange.huobipro]
+    TradableType.coin: [Exchange.binance, Exchange.huobipro],
 }
 
 
@@ -201,7 +198,16 @@ from . import zvt_context
 zvt_context = zvt_context
 
 # the __all__ is generated
-__all__ = ['IntervalLevel', 'AdjustType', 'ActorType', 'TradableType', 'Exchange', 'tradable_type_map_exchanges', 'get_entity_exchanges', 'zvt_context']
+__all__ = [
+    "IntervalLevel",
+    "AdjustType",
+    "ActorType",
+    "TradableType",
+    "Exchange",
+    "tradable_type_map_exchanges",
+    "get_entity_exchanges",
+    "zvt_context",
+]
 
 # __init__.py structure:
 # common code of the package
@@ -210,4 +216,5 @@ __all__ = ['IntervalLevel', 'AdjustType', 'ActorType', 'TradableType', 'Exchange
 # import all from submodule schema
 from .schema import *
 from .schema import __all__ as _schema_all
-__all__ += _schema_all
\ No newline at end of file
+
+__all__ += _schema_all
