@@ -36,10 +36,9 @@ def get_db_name(data_schema: DeclarativeMeta) -> str:
             return db_name
 
 
-def get_db_engine(provider: str,
-                  db_name: str = None,
-                  data_schema: object = None,
-                  data_path: str = zvt_env['data_path']) -> Engine:
+def get_db_engine(
+    provider: str, db_name: str = None, data_schema: object = None, data_path: str = zvt_env["data_path"]
+) -> Engine:
     """
     get db engine of the (provider,db_name) or (provider,data_schema)
 
@@ -57,12 +56,12 @@ def get_db_engine(provider: str,
     if data_schema:
         db_name = get_db_name(data_schema=data_schema)
 
-    db_path = os.path.join(data_path, '{}_{}.db?check_same_thread=False'.format(provider, db_name))
+    db_path = os.path.join(data_path, "{}_{}.db?check_same_thread=False".format(provider, db_name))
 
-    engine_key = '{}_{}'.format(provider, db_name)
+    engine_key = "{}_{}".format(provider, db_name)
     db_engine = zvt_context.db_engine_map.get(engine_key)
     if not db_engine:
-        db_engine = create_engine('sqlite:///' + db_path, echo=False)
+        db_engine = create_engine("sqlite:///" + db_path, echo=False)
         zvt_context.db_engine_map[engine_key] = db_engine
     return db_engine
 
@@ -86,10 +85,7 @@ def get_schemas(provider: str) -> List[DeclarativeMeta]:
     return schemas
 
 
-def get_db_session(provider: str,
-                   db_name: str = None,
-                   data_schema: object = None,
-                   force_new: bool = False) -> Session:
+def get_db_session(provider: str, db_name: str = None, data_schema: object = None, force_new: bool = False) -> Session:
     """
     get db session of the (provider,db_name) or (provider,data_schema)
 
@@ -108,7 +104,7 @@ def get_db_session(provider: str,
     if data_schema:
         db_name = get_db_name(data_schema=data_schema)
 
-    session_key = '{}_{}'.format(provider, db_name)
+    session_key = "{}_{}".format(provider, db_name)
 
     if force_new:
         return get_db_session_factory(provider, db_name, data_schema)()
@@ -120,9 +116,7 @@ def get_db_session(provider: str,
     return session
 
 
-def get_db_session_factory(provider: str,
-                           db_name: str = None,
-                           data_schema: object = None):
+def get_db_session_factory(provider: str, db_name: str = None, data_schema: object = None):
     """
     get db session factory of the (provider,db_name) or (provider,data_schema)
 
@@ -138,7 +132,7 @@ def get_db_session_factory(provider: str,
     if data_schema:
         db_name = get_db_name(data_schema=data_schema)
 
-    session_key = '{}_{}'.format(provider, db_name)
+    session_key = "{}_{}".format(provider, db_name)
     session = zvt_context.db_session_map.get(session_key)
     if not session:
         session = sessionmaker()
@@ -148,7 +142,7 @@ def get_db_session_factory(provider: str,
 
 def domain_name_to_table_name(domain_name: str) -> str:
     parts = []
-    part = ''
+    part = ""
     for c in domain_name:
         if c.isupper() or c.isdigit():
             if part:
@@ -160,7 +154,7 @@ def domain_name_to_table_name(domain_name: str) -> str:
     parts.append(part)
 
     if len(parts) > 1:
-        return '_'.join(parts)
+        return "_".join(parts)
     elif parts:
         return parts[0]
 
@@ -174,8 +168,8 @@ def table_name_to_domain_name(table_name: str) -> DeclarativeMeta:
     :return:
     :rtype:
     """
-    parts = table_name.split('_')
-    domain_name = ''
+    parts = table_name.split("_")
+    domain_name = ""
     for part in parts:
         domain_name = domain_name + part.capitalize()
     return domain_name
@@ -219,16 +213,18 @@ def get_schema_columns(schema: DeclarativeMeta) -> List[str]:
     return schema.__table__.columns.keys()
 
 
-def common_filter(query: Query,
-                  data_schema,
-                  start_timestamp=None,
-                  end_timestamp=None,
-                  filters=None,
-                  order=None,
-                  limit=None,
-                  time_field='timestamp'):
+def common_filter(
+    query: Query,
+    data_schema,
+    start_timestamp=None,
+    end_timestamp=None,
+    filters=None,
+    order=None,
+    limit=None,
+    time_field="timestamp",
+):
     assert data_schema is not None
-    time_col = eval('data_schema.{}'.format(time_field))
+    time_col = eval("data_schema.{}".format(time_field))
 
     if start_timestamp:
         query = query.filter(time_col >= to_pd_timestamp(start_timestamp))
@@ -262,7 +258,7 @@ def del_data(data_schema: Type[Mixin], filters: List = None, provider=None):
 
 
 def get_one(data_schema, id: str, provider: str = None, session: Session = None):
-    if 'providers' not in data_schema.__dict__:
+    if "providers" not in data_schema.__dict__:
         logger.error("no provider registered for: {}", data_schema)
     if not provider:
         provider = data_schema.providers[0]
@@ -273,26 +269,28 @@ def get_one(data_schema, id: str, provider: str = None, session: Session = None)
     return session.query(data_schema).get(id)
 
 
-def get_data(data_schema: Type[Mixin],
-             ids: List[str] = None,
-             entity_ids: List[str] = None,
-             entity_id: str = None,
-             codes: List[str] = None,
-             code: str = None,
-             level: Union[IntervalLevel, str] = None,
-             provider: str = None,
-             columns: List = None,
-             col_label: dict = None,
-             return_type: str = 'df',
-             start_timestamp: Union[pd.Timestamp, str] = None,
-             end_timestamp: Union[pd.Timestamp, str] = None,
-             filters: List = None,
-             session: Session = None,
-             order=None,
-             limit: int = None,
-             index: Union[str, list] = None,
-             time_field: str = 'timestamp'):
-    if 'providers' not in data_schema.__dict__:
+def get_data(
+    data_schema: Type[Mixin],
+    ids: List[str] = None,
+    entity_ids: List[str] = None,
+    entity_id: str = None,
+    codes: List[str] = None,
+    code: str = None,
+    level: Union[IntervalLevel, str] = None,
+    provider: str = None,
+    columns: List = None,
+    col_label: dict = None,
+    return_type: str = "df",
+    start_timestamp: Union[pd.Timestamp, str] = None,
+    end_timestamp: Union[pd.Timestamp, str] = None,
+    filters: List = None,
+    session: Session = None,
+    order=None,
+    limit: int = None,
+    index: Union[str, list] = None,
+    time_field: str = "timestamp",
+):
+    if "providers" not in data_schema.__dict__:
         logger.error("no provider registered for: {}", data_schema)
     if not provider:
         provider = data_schema.providers[0]
@@ -300,7 +298,7 @@ def get_data(data_schema: Type[Mixin],
     if not session:
         session = get_db_session(provider=provider, data_schema=data_schema)
 
-    time_col = eval('data_schema.{}'.format(time_field))
+    time_col = eval("data_schema.{}".format(time_field))
 
     if columns:
         # support str
@@ -308,7 +306,7 @@ def get_data(data_schema: Type[Mixin],
             columns_ = []
             for col in columns:
                 if isinstance(col, str):
-                    columns_.append(eval('data_schema.{}'.format(col)))
+                    columns_.append(eval("data_schema.{}".format(col)))
                 else:
                     columns_.append(col)
             columns = columns_
@@ -352,19 +350,26 @@ def get_data(data_schema: Type[Mixin],
         except Exception as e:
             pass
 
-    query = common_filter(query, data_schema=data_schema, start_timestamp=start_timestamp,
-                          end_timestamp=end_timestamp, filters=filters, order=order, limit=limit,
-                          time_field=time_field)
+    query = common_filter(
+        query,
+        data_schema=data_schema,
+        start_timestamp=start_timestamp,
+        end_timestamp=end_timestamp,
+        filters=filters,
+        order=order,
+        limit=limit,
+        time_field=time_field,
+    )
 
-    if return_type == 'df':
+    if return_type == "df":
         df = pd.read_sql(query.statement, query.session.bind)
         if pd_is_not_null(df):
             if index:
                 df = index_df(df, index=index, time_field=time_field)
         return df
-    elif return_type == 'domain':
+    elif return_type == "domain":
         return query.all()
-    elif return_type == 'dict':
+    elif return_type == "dict":
         return [item.__dict__ for item in query.all()]
 
 
@@ -395,10 +400,10 @@ def get_group(provider, data_schema, column, group_func=func.count, session=None
 
 
 def decode_entity_id(entity_id: str):
-    result = entity_id.split('_')
+    result = entity_id.split("_")
     entity_type = result[0]
     exchange = result[1]
-    code = ''.join(result[2:])
+    code = "".join(result[2:])
     return entity_type, exchange, code
 
 
@@ -417,12 +422,14 @@ def get_entity_code(entity_id: str):
     return code
 
 
-def df_to_db(df: pd.DataFrame,
-             data_schema: DeclarativeMeta,
-             provider: str,
-             force_update: bool = False,
-             sub_size: int = 5000,
-             drop_duplicates: bool = True) -> object:
+def df_to_db(
+    df: pd.DataFrame,
+    data_schema: DeclarativeMeta,
+    provider: str,
+    force_update: bool = False,
+    sub_size: int = 5000,
+    drop_duplicates: bool = True,
+) -> object:
     """
     FIXME:improve
     store the df to db
@@ -438,9 +445,9 @@ def df_to_db(df: pd.DataFrame,
     if not pd_is_not_null(df):
         return 0
 
-    if drop_duplicates and df.duplicated(subset='id').any():
-        logger.warning(f'remove duplicated:{df[df.duplicated()]}')
-        df = df.drop_duplicates(subset='id', keep='last')
+    if drop_duplicates and df.duplicated(subset="id").any():
+        logger.warning(f"remove duplicated:{df[df.duplicated()]}")
+        df = df.drop_duplicates(subset="id", keep="last")
 
     db_engine = get_db_engine(provider, data_schema=data_schema)
 
@@ -448,7 +455,7 @@ def df_to_db(df: pd.DataFrame,
     cols = set(df.columns.tolist()) & set(schema_cols)
 
     if not cols:
-        print('wrong cols')
+        print("wrong cols")
         return 0
 
     df = df[cols]
@@ -468,51 +475,53 @@ def df_to_db(df: pd.DataFrame,
     saved = 0
 
     for step in range(step_size):
-        df_current = df.iloc[sub_size * step:sub_size * (step + 1)]
+        df_current = df.iloc[sub_size * step : sub_size * (step + 1)]
         if force_update:
             session = get_db_session(provider=provider, data_schema=data_schema)
             ids = df_current["id"].tolist()
             if len(ids) == 1:
                 sql = f'delete from `{data_schema.__tablename__}` where id = "{ids[0]}"'
             else:
-                sql = f'delete from `{data_schema.__tablename__}` where id in {tuple(ids)}'
+                sql = f"delete from `{data_schema.__tablename__}` where id in {tuple(ids)}"
 
             session.execute(sql)
             session.commit()
 
         else:
-            current = get_data(data_schema=data_schema, columns=[data_schema.id], provider=provider,
-                               ids=df_current['id'].tolist())
+            current = get_data(
+                data_schema=data_schema, columns=[data_schema.id], provider=provider, ids=df_current["id"].tolist()
+            )
             if pd_is_not_null(current):
-                df_current = df_current[~df_current['id'].isin(current['id'])]
+                df_current = df_current[~df_current["id"].isin(current["id"])]
 
         if pd_is_not_null(df_current):
             saved = saved + len(df_current)
-            df_current.to_sql(data_schema.__tablename__, db_engine, index=False, if_exists='append')
+            df_current.to_sql(data_schema.__tablename__, db_engine, index=False, if_exists="append")
 
     return saved
 
 
 def get_entities(
-        entity_schema: Type[TradableEntity] = None,
-        entity_type: str = None,
-        exchanges: List[str] = None,
-        ids: List[str] = None,
-        entity_ids: List[str] = None,
-        entity_id: str = None,
-        codes: List[str] = None,
-        code: str = None,
-        provider: str = None,
-        columns: List = None,
-        col_label: dict = None,
-        return_type: str = 'df',
-        start_timestamp: Union[pd.Timestamp, str] = None,
-        end_timestamp: Union[pd.Timestamp, str] = None,
-        filters: List = None,
-        session: Session = None,
-        order=None,
-        limit: int = None,
-        index: Union[str, list] = 'code') -> List:
+    entity_schema: Type[TradableEntity] = None,
+    entity_type: str = None,
+    exchanges: List[str] = None,
+    ids: List[str] = None,
+    entity_ids: List[str] = None,
+    entity_id: str = None,
+    codes: List[str] = None,
+    code: str = None,
+    provider: str = None,
+    columns: List = None,
+    col_label: dict = None,
+    return_type: str = "df",
+    start_timestamp: Union[pd.Timestamp, str] = None,
+    end_timestamp: Union[pd.Timestamp, str] = None,
+    filters: List = None,
+    session: Session = None,
+    order=None,
+    limit: int = None,
+    index: Union[str, list] = "code",
+) -> List:
     if not entity_schema:
         entity_schema = zvt_context.tradable_schema_map[entity_type]
 
@@ -528,24 +537,68 @@ def get_entities(
         else:
             filters = [entity_schema.exchange.in_(exchanges)]
 
-    return get_data(data_schema=entity_schema, ids=ids, entity_ids=entity_ids, entity_id=entity_id, codes=codes,
-                    code=code, level=None, provider=provider, columns=columns, col_label=col_label,
-                    return_type=return_type, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
-                    filters=filters, session=session, order=order, limit=limit, index=index)
+    return get_data(
+        data_schema=entity_schema,
+        ids=ids,
+        entity_ids=entity_ids,
+        entity_id=entity_id,
+        codes=codes,
+        code=code,
+        level=None,
+        provider=provider,
+        columns=columns,
+        col_label=col_label,
+        return_type=return_type,
+        start_timestamp=start_timestamp,
+        end_timestamp=end_timestamp,
+        filters=filters,
+        session=session,
+        order=order,
+        limit=limit,
+        index=index,
+    )
 
 
-def get_entity_ids(entity_type='stock', entity_schema: TradableEntity = None, exchanges=None, codes=None, provider=None,
-                   filters=None):
-    df = get_entities(entity_type=entity_type, entity_schema=entity_schema, exchanges=exchanges, codes=codes,
-                      provider=provider, filters=filters)
+def get_entity_ids(
+    entity_type="stock", entity_schema: TradableEntity = None, exchanges=None, codes=None, provider=None, filters=None
+):
+    df = get_entities(
+        entity_type=entity_type,
+        entity_schema=entity_schema,
+        exchanges=exchanges,
+        codes=codes,
+        provider=provider,
+        filters=filters,
+    )
     if pd_is_not_null(df):
-        return df['entity_id'].to_list()
+        return df["entity_id"].to_list()
     return None
 
 
 # the __all__ is generated
-__all__ = ['get_db_name', 'get_db_engine', 'get_schemas', 'get_db_session', 'get_db_session_factory',
-           'domain_name_to_table_name', 'table_name_to_domain_name', 'get_entity_schema', 'get_schema_by_name',
-           'get_schema_columns', 'common_filter', 'del_data', 'get_one', 'get_data', 'data_exist', 'get_data_count',
-           'get_group', 'decode_entity_id', 'get_entity_type', 'get_entity_exchange', 'get_entity_code', 'df_to_db',
-           'get_entities', 'get_entity_ids']
+__all__ = [
+    "get_db_name",
+    "get_db_engine",
+    "get_schemas",
+    "get_db_session",
+    "get_db_session_factory",
+    "domain_name_to_table_name",
+    "table_name_to_domain_name",
+    "get_entity_schema",
+    "get_schema_by_name",
+    "get_schema_columns",
+    "common_filter",
+    "del_data",
+    "get_one",
+    "get_data",
+    "data_exist",
+    "get_data_count",
+    "get_group",
+    "decode_entity_id",
+    "get_entity_type",
+    "get_entity_exchange",
+    "get_entity_code",
+    "df_to_db",
+    "get_entities",
+    "get_entity_ids",
+]
