@@ -14,8 +14,15 @@ from zvt.contract.base import StatefulService
 from zvt.contract.schema import Mixin, TradableEntity
 from zvt.contract.zvt_info import RecorderState
 from zvt.utils import pd_is_not_null
-from zvt.utils.time_utils import to_pd_timestamp, TIME_FORMAT_DAY, to_time_str, \
-    evaluate_size_from_timestamp, is_in_same_interval, now_pd_timestamp, now_time_str
+from zvt.utils.time_utils import (
+    to_pd_timestamp,
+    TIME_FORMAT_DAY,
+    to_time_str,
+    evaluate_size_from_timestamp,
+    is_in_same_interval,
+    now_pd_timestamp,
+    now_time_str,
+)
 from zvt.utils.utils import fill_domain_from_dict
 
 
@@ -23,9 +30,9 @@ class Meta(type):
     def __new__(meta, name, bases, class_dict):
         cls = type.__new__(meta, name, bases, class_dict)
         # register the recorder class to the data_schema
-        if hasattr(cls, 'data_schema') and hasattr(cls, 'provider'):
+        if hasattr(cls, "data_schema") and hasattr(cls, "provider"):
             if cls.data_schema and issubclass(cls.data_schema, Mixin):
-                print(f'{cls.__name__}:{cls.data_schema.__name__}')
+                print(f"{cls.__name__}:{cls.data_schema.__name__}")
                 cls.data_schema.register_recorder_cls(cls.provider, cls)
         return cls
 
@@ -50,15 +57,15 @@ class Recorder(StatefulService, metaclass=Meta):
         assert self.data_schema is not None
         if self.provider not in self.data_schema.providers:
             self.logger.error(
-                f'provider: {self.provider} is not registered for {self.data_schema}({self.data_schema.providers})')
+                f"provider: {self.provider} is not registered for {self.data_schema}({self.data_schema.providers})"
+            )
             assert False
 
         self.force_update = force_update
         self.sleeping_time = sleeping_time
 
         # using to do db operations
-        self.session = get_db_session(provider=self.provider,
-                                      data_schema=self.data_schema)
+        self.session = get_db_session(provider=self.provider, data_schema=self.data_schema)
 
     def run(self):
         raise NotImplementedError
@@ -70,7 +77,7 @@ class Recorder(StatefulService, metaclass=Meta):
             sleeping_time = self.sleeping_time
 
         if sleeping_time and sleeping_time > 0:
-            self.logger.info(f'sleeping {sleeping_time} seconds')
+            self.logger.info(f"sleeping {sleeping_time} seconds")
             time.sleep(self.sleeping_time)
 
 
@@ -79,16 +86,18 @@ class EntityEventRecorder(Recorder):
     entity_provider: str = None
     entity_schema: TradableEntity = None
 
-    def __init__(self,
-                 force_update=False,
-                 sleeping_time=10,
-                 exchanges=None,
-                 entity_ids=None,
-                 code=None,
-                 codes=None,
-                 day_data=False,
-                 entity_filters=None,
-                 ignore_failed=True) -> None:
+    def __init__(
+        self,
+        force_update=False,
+        sleeping_time=10,
+        exchanges=None,
+        entity_ids=None,
+        code=None,
+        codes=None,
+        day_data=False,
+        entity_filters=None,
+        ignore_failed=True,
+    ) -> None:
         """
         :param code:
         :param ignore_failed:
@@ -133,46 +142,60 @@ class EntityEventRecorder(Recorder):
             self.entity_session = get_db_session(provider=self.entity_provider, data_schema=self.entity_schema)
 
         if self.day_data:
-            df = self.data_schema.query_data(start_timestamp=now_time_str(), columns=['entity_id', 'timestamp'],
-                                             provider=self.provider)
+            df = self.data_schema.query_data(
+                start_timestamp=now_time_str(), columns=["entity_id", "timestamp"], provider=self.provider
+            )
             if pd_is_not_null(df):
-                entity_ids = df['entity_id'].tolist()
-                self.logger.info(f'ignore entity_ids:{entity_ids}')
+                entity_ids = df["entity_id"].tolist()
+                self.logger.info(f"ignore entity_ids:{entity_ids}")
                 if self.entity_filters:
                     self.entity_filters.append(self.entity_schema.entity_id.notin_(entity_ids))
                 else:
                     self.entity_filters = [self.entity_schema.entity_id.notin_(entity_ids)]
 
         # init the entity list
-        self.entities = get_entities(session=self.entity_session,
-                                     entity_schema=self.entity_schema,
-                                     exchanges=self.exchanges,
-                                     entity_ids=self.entity_ids,
-                                     codes=self.codes,
-                                     return_type='domain',
-                                     provider=self.entity_provider,
-                                     filters=self.entity_filters)
+        self.entities = get_entities(
+            session=self.entity_session,
+            entity_schema=self.entity_schema,
+            exchanges=self.exchanges,
+            entity_ids=self.entity_ids,
+            codes=self.codes,
+            return_type="domain",
+            provider=self.entity_provider,
+            filters=self.entity_filters,
+        )
 
 
 class TimeSeriesDataRecorder(EntityEventRecorder):
     default_size = 2000
 
-    def __init__(self,
-                 force_update=False,
-                 sleeping_time=5,
-                 exchanges=None,
-                 entity_ids=None,
-                 code=None,
-                 codes=None,
-                 day_data=False,
-                 entity_filters=None,
-                 ignore_failed=True,
-                 real_time=False,
-                 fix_duplicate_way='add',
-                 start_timestamp=None,
-                 end_timestamp=None) -> None:
-        super().__init__(force_update, sleeping_time, exchanges, entity_ids, code=code, codes=codes, day_data=day_data,
-                         entity_filters=entity_filters, ignore_failed=ignore_failed)
+    def __init__(
+        self,
+        force_update=False,
+        sleeping_time=5,
+        exchanges=None,
+        entity_ids=None,
+        code=None,
+        codes=None,
+        day_data=False,
+        entity_filters=None,
+        ignore_failed=True,
+        real_time=False,
+        fix_duplicate_way="add",
+        start_timestamp=None,
+        end_timestamp=None,
+    ) -> None:
+        super().__init__(
+            force_update,
+            sleeping_time,
+            exchanges,
+            entity_ids,
+            code=code,
+            codes=codes,
+            day_data=day_data,
+            entity_filters=entity_filters,
+            ignore_failed=ignore_failed,
+        )
 
         self.real_time = real_time
         self.close_hour, self.close_minute = self.entity_schema.get_close_hour_and_minute()
@@ -181,15 +204,17 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
         self.end_timestamp = to_pd_timestamp(end_timestamp)
 
     def get_latest_saved_record(self, entity):
-        order = eval('self.data_schema.{}.desc()'.format(self.get_evaluated_time_field()))
+        order = eval("self.data_schema.{}.desc()".format(self.get_evaluated_time_field()))
 
-        records = get_data(entity_id=entity.id,
-                           provider=self.provider,
-                           data_schema=self.data_schema,
-                           order=order,
-                           limit=1,
-                           return_type='domain',
-                           session=self.session)
+        records = get_data(
+            entity_id=entity.id,
+            provider=self.provider,
+            data_schema=self.data_schema,
+            order=order,
+            limit=1,
+            return_type="domain",
+            session=self.session,
+        )
         if records:
             return records[0]
         return None
@@ -203,7 +228,7 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
         latest_saved_record = self.get_latest_saved_record(entity=entity)
 
         if latest_saved_record:
-            latest_timestamp = eval('latest_saved_record.{}'.format(self.get_evaluated_time_field()))
+            latest_timestamp = eval("latest_saved_record.{}".format(self.get_evaluated_time_field()))
         else:
             latest_timestamp = entity.timestamp
 
@@ -249,10 +274,10 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
         the timestamp field for evaluating time range of recorder,used in get_latest_saved_record
 
         """
-        return 'timestamp'
+        return "timestamp"
 
     def get_original_time_field(self):
-        return 'timestamp'
+        return "timestamp"
 
     def generate_domain_id(self, entity, original_data, time_fmt=TIME_FORMAT_DAY):
         """
@@ -290,11 +315,17 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
         # optional way
         # item = self.session.query(self.data_schema).get(the_id)
 
-        items = get_data(data_schema=self.data_schema, session=self.session, provider=self.provider,
-                         entity_id=entity.id, filters=[self.data_schema.id == the_id], return_type='domain')
+        items = get_data(
+            data_schema=self.data_schema,
+            session=self.session,
+            provider=self.provider,
+            entity_id=entity.id,
+            filters=[self.data_schema.id == the_id],
+            return_type="domain",
+        )
 
         if items and not self.force_update:
-            self.logger.info('ignore the data {}:{} saved before'.format(self.data_schema, the_id))
+            self.logger.info("ignore the data {}:{} saved before".format(self.data_schema, the_id))
             return got_new_data, None
 
         if not items:
@@ -305,17 +336,12 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
             except Exception as e:
                 self.logger.exception(e)
 
-            if 'name' in get_schema_columns(self.data_schema):
-                domain_item = self.data_schema(id=the_id,
-                                               code=entity.code,
-                                               name=entity.name,
-                                               entity_id=entity.id,
-                                               timestamp=timestamp)
+            if "name" in get_schema_columns(self.data_schema):
+                domain_item = self.data_schema(
+                    id=the_id, code=entity.code, name=entity.name, entity_id=entity.id, timestamp=timestamp
+                )
             else:
-                domain_item = self.data_schema(id=the_id,
-                                               code=entity.code,
-                                               entity_id=entity.id,
-                                               timestamp=timestamp)
+                domain_item = self.data_schema(id=the_id, code=entity.code, entity_id=entity.id, timestamp=timestamp)
             got_new_data = True
         else:
             domain_item = items[0]
@@ -344,7 +370,9 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
 
             self.logger.info(
                 "persist {} for entity_id:{},time interval:[{},{}]".format(
-                    self.data_schema, entity.id, first_timestamp, last_timestamp))
+                    self.data_schema, entity.id, first_timestamp, last_timestamp
+                )
+            )
 
             self.session.add_all(domain_list)
             self.session.commit()
@@ -370,36 +398,34 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
             count = len(unfinished_items)
             for index, entity_item in enumerate(unfinished_items):
                 try:
-                    self.logger.info(f'run to {index + 1}/{count}')
+                    self.logger.info(f"run to {index + 1}/{count}")
 
                     start_timestamp, end_timestamp, size, timestamps = self.evaluate_start_end_size_timestamps(
-                        entity_item)
+                        entity_item
+                    )
                     size = int(size)
 
                     if timestamps:
-                        self.logger.info('entity_id:{},evaluate_start_end_size_timestamps result:{},{},{},{}-{}'.format(
-                            entity_item.id,
-                            start_timestamp,
-                            end_timestamp,
-                            size,
-                            timestamps[0],
-                            timestamps[-1]))
+                        self.logger.info(
+                            "entity_id:{},evaluate_start_end_size_timestamps result:{},{},{},{}-{}".format(
+                                entity_item.id, start_timestamp, end_timestamp, size, timestamps[0], timestamps[-1]
+                            )
+                        )
                     else:
-                        self.logger.info('entity_id:{},evaluate_start_end_size_timestamps result:{},{},{},{}'.format(
-                            entity_item.id,
-                            start_timestamp,
-                            end_timestamp,
-                            size,
-                            timestamps))
+                        self.logger.info(
+                            "entity_id:{},evaluate_start_end_size_timestamps result:{},{},{},{}".format(
+                                entity_item.id, start_timestamp, end_timestamp, size, timestamps
+                            )
+                        )
 
                     # no more to record
                     if size == 0:
                         finished_items.append(entity_item)
                         self.logger.info(
                             "finish recording {} for entity_id:{},latest_timestamp:{}".format(
-                                self.data_schema,
-                                entity_item.id,
-                                start_timestamp))
+                                self.data_schema, entity_item.id, start_timestamp
+                            )
+                        )
                         self.on_finish_entity(entity_item)
                         continue
 
@@ -407,8 +433,9 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
                     if index != 0:
                         self.sleep()
 
-                    original_list = self.record(entity_item, start=start_timestamp, end=end_timestamp, size=size,
-                                                timestamps=timestamps)
+                    original_list = self.record(
+                        entity_item, start=start_timestamp, end=end_timestamp, size=size, timestamps=timestamps
+                    )
 
                     all_duplicated = True
 
@@ -425,11 +452,11 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
                                 duplicate = [item for item in domain_list if item.id == domain_item.id]
                                 if duplicate:
                                     # regenerate the id
-                                    if self.fix_duplicate_way == 'add':
+                                    if self.fix_duplicate_way == "add":
                                         domain_item.id = "{}_{}".format(domain_item.id, uuid.uuid1())
                                     # ignore
                                     else:
-                                        self.logger.info(f'ignore original duplicate item:{domain_item.id}')
+                                        self.logger.info(f"ignore original duplicate item:{domain_item.id}")
                                         continue
 
                                 domain_list.append(domain_item)
@@ -437,7 +464,7 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
                         if domain_list:
                             self.persist(entity_item, domain_list)
                         else:
-                            self.logger.info('just got {} duplicated data in this cycle'.format(len(original_list)))
+                            self.logger.info("just got {} duplicated data in this cycle".format(len(original_list)))
 
                     # could not get more data
                     entity_finished = False
@@ -447,14 +474,13 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
                             entity_finished = True
 
                         # realtime and to the close time
-                        if self.real_time and \
-                                (self.close_hour is not None) and \
-                                (self.close_minute is not None):
+                        if self.real_time and (self.close_hour is not None) and (self.close_minute is not None):
                             current_timestamp = pd.Timestamp.now()
                             if current_timestamp.hour >= self.close_hour:
                                 if current_timestamp.minute - self.close_minute >= 5:
                                     self.logger.info(
-                                        '{} now is the close time:{}'.format(entity_item.id, current_timestamp))
+                                        "{} now is the close time:{}".format(entity_item.id, current_timestamp)
+                                    )
 
                                     entity_finished = True
 
@@ -464,19 +490,20 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
 
                         latest_saved_record = self.get_latest_saved_record(entity=entity_item)
                         if latest_saved_record:
-                            start_timestamp = eval('latest_saved_record.{}'.format(self.get_evaluated_time_field()))
+                            start_timestamp = eval("latest_saved_record.{}".format(self.get_evaluated_time_field()))
 
                         self.logger.info(
                             "finish recording {} for entity_id:{},latest_timestamp:{}".format(
-                                self.data_schema,
-                                entity_item.id,
-                                start_timestamp))
+                                self.data_schema, entity_item.id, start_timestamp
+                            )
+                        )
                         self.on_finish_entity(entity_item)
                         continue
 
                 except Exception as e:
                     self.logger.exception(
-                        "recording data for entity_id:{},{},error:{}".format(entity_item.id, self.data_schema, e))
+                        "recording data for entity_id:{},{},error:{}".format(entity_item.id, self.data_schema, e)
+                    )
                     raising_exception = e
                     finished_items = unfinished_items
                     break
@@ -493,45 +520,60 @@ class TimeSeriesDataRecorder(EntityEventRecorder):
 
 
 class FixedCycleDataRecorder(TimeSeriesDataRecorder):
-    def __init__(self,
-                 force_update=True,
-                 sleeping_time=10,
-                 exchanges=None,
-                 entity_ids=None,
-                 code=None,
-                 codes=None,
-                 day_data=False,
-                 entity_filters=None,
-                 ignore_failed=True,
-                 real_time=False,
-                 fix_duplicate_way='ignore',
-                 start_timestamp=None,
-                 end_timestamp=None,
-                 level=IntervalLevel.LEVEL_1DAY,
-                 kdata_use_begin_time=False,
-                 one_day_trading_minutes=24 * 60) -> None:
-        super().__init__(force_update, sleeping_time, exchanges, entity_ids, code=code, codes=codes, day_data=day_data,
-                         entity_filters=entity_filters, ignore_failed=ignore_failed, real_time=real_time,
-                         fix_duplicate_way=fix_duplicate_way, start_timestamp=start_timestamp,
-                         end_timestamp=end_timestamp)
+    def __init__(
+        self,
+        force_update=True,
+        sleeping_time=10,
+        exchanges=None,
+        entity_ids=None,
+        code=None,
+        codes=None,
+        day_data=False,
+        entity_filters=None,
+        ignore_failed=True,
+        real_time=False,
+        fix_duplicate_way="ignore",
+        start_timestamp=None,
+        end_timestamp=None,
+        level=IntervalLevel.LEVEL_1DAY,
+        kdata_use_begin_time=False,
+        one_day_trading_minutes=24 * 60,
+    ) -> None:
+        super().__init__(
+            force_update,
+            sleeping_time,
+            exchanges,
+            entity_ids,
+            code=code,
+            codes=codes,
+            day_data=day_data,
+            entity_filters=entity_filters,
+            ignore_failed=ignore_failed,
+            real_time=real_time,
+            fix_duplicate_way=fix_duplicate_way,
+            start_timestamp=start_timestamp,
+            end_timestamp=end_timestamp,
+        )
 
         self.level = IntervalLevel(level)
         self.kdata_use_begin_time = kdata_use_begin_time
         self.one_day_trading_minutes = one_day_trading_minutes
 
     def get_latest_saved_record(self, entity):
-        order = eval('self.data_schema.{}.desc()'.format(self.get_evaluated_time_field()))
+        order = eval("self.data_schema.{}.desc()".format(self.get_evaluated_time_field()))
 
         # 对于k线这种数据，最后一个记录有可能是没完成的，所以取两个
         # 同一周期内只保留最新的一个数据
-        records = get_data(entity_id=entity.id,
-                           provider=self.provider,
-                           data_schema=self.data_schema,
-                           order=order,
-                           limit=2,
-                           return_type='domain',
-                           session=self.session,
-                           level=self.level)
+        records = get_data(
+            entity_id=entity.id,
+            provider=self.provider,
+            data_schema=self.data_schema,
+            order=order,
+            limit=2,
+            return_type="domain",
+            session=self.session,
+            level=self.level,
+        )
         if records:
             # delete unfinished kdata
             if len(records) == 2:
@@ -559,8 +601,11 @@ class FixedCycleDataRecorder(TimeSeriesDataRecorder):
         if not latest_saved_timestamp:
             return None, None, self.default_size, None
 
-        size = evaluate_size_from_timestamp(start_timestamp=latest_saved_timestamp, level=self.level,
-                                            one_day_trading_minutes=self.one_day_trading_minutes)
+        size = evaluate_size_from_timestamp(
+            start_timestamp=latest_saved_timestamp,
+            level=self.level,
+            one_day_trading_minutes=self.one_day_trading_minutes,
+        )
 
         if self.start_timestamp:
             start = max(self.start_timestamp, latest_saved_timestamp)
@@ -571,25 +616,37 @@ class FixedCycleDataRecorder(TimeSeriesDataRecorder):
 
 
 class TimestampsDataRecorder(TimeSeriesDataRecorder):
-
-    def __init__(self,
-                 force_update=False,
-                 sleeping_time=5,
-                 exchanges=None,
-                 entity_ids=None,
-                 code=None,
-                 codes=None,
-                 day_data=False,
-                 entity_filters=None,
-                 ignore_failed=True,
-                 real_time=False,
-                 fix_duplicate_way='add',
-                 start_timestamp=None,
-                 end_timestamp=None) -> None:
-        super().__init__(force_update, sleeping_time, exchanges, entity_ids, code=code, codes=codes, day_data=day_data,
-                         entity_filters=entity_filters, ignore_failed=ignore_failed, real_time=real_time,
-                         fix_duplicate_way=fix_duplicate_way, start_timestamp=start_timestamp,
-                         end_timestamp=end_timestamp)
+    def __init__(
+        self,
+        force_update=False,
+        sleeping_time=5,
+        exchanges=None,
+        entity_ids=None,
+        code=None,
+        codes=None,
+        day_data=False,
+        entity_filters=None,
+        ignore_failed=True,
+        real_time=False,
+        fix_duplicate_way="add",
+        start_timestamp=None,
+        end_timestamp=None,
+    ) -> None:
+        super().__init__(
+            force_update,
+            sleeping_time,
+            exchanges,
+            entity_ids,
+            code=code,
+            codes=codes,
+            day_data=day_data,
+            entity_filters=entity_filters,
+            ignore_failed=ignore_failed,
+            real_time=real_time,
+            fix_duplicate_way=fix_duplicate_way,
+            start_timestamp=start_timestamp,
+            end_timestamp=end_timestamp,
+        )
         self.security_timestamps_map = {}
 
     def init_timestamps(self, entity_item) -> List[pd.Timestamp]:
@@ -612,13 +669,12 @@ class TimestampsDataRecorder(TimeSeriesDataRecorder):
 
         timestamps.sort()
 
-        self.logger.info(
-            'entity_id:{},timestamps start:{},end:{}'.format(entity.id, timestamps[0], timestamps[-1]))
+        self.logger.info("entity_id:{},timestamps start:{},end:{}".format(entity.id, timestamps[0], timestamps[-1]))
 
         latest_record = self.get_latest_saved_record(entity=entity)
 
         if latest_record:
-            self.logger.info('latest record timestamp:{}'.format(latest_record.timestamp))
+            self.logger.info("latest record timestamp:{}".format(latest_record.timestamp))
             timestamps = [t for t in timestamps if t >= latest_record.timestamp]
 
             if timestamps:
@@ -629,4 +685,11 @@ class TimestampsDataRecorder(TimeSeriesDataRecorder):
 
 
 # the __all__ is generated
-__all__ = ['Meta', 'Recorder', 'EntityEventRecorder', 'TimeSeriesDataRecorder', 'FixedCycleDataRecorder', 'TimestampsDataRecorder']
\ No newline at end of file
+__all__ = [
+    "Meta",
+    "Recorder",
+    "EntityEventRecorder",
+    "TimeSeriesDataRecorder",
+    "FixedCycleDataRecorder",
+    "TimestampsDataRecorder",
+]
