@@ -32,7 +32,7 @@ class Mixin(object):
 
     @classmethod
     def time_field(cls):
-        return 'timestamp'
+        return "timestamp"
 
     @classmethod
     def register_recorder_cls(cls, provider, recorder_cls):
@@ -43,7 +43,7 @@ class Mixin(object):
         :param recorder_cls:
         """
         # don't make provider_map_recorder as class field,it should be created for the sub class as need
-        if not hasattr(cls, 'provider_map_recorder'):
+        if not hasattr(cls, "provider_map_recorder"):
             cls.provider_map_recorder = {}
 
         if provider not in cls.provider_map_recorder:
@@ -52,7 +52,7 @@ class Mixin(object):
     @classmethod
     def register_provider(cls, provider):
         # don't make providers as class field,it should be created for the sub class as need
-        if not hasattr(cls, 'providers'):
+        if not hasattr(cls, "providers"):
             cls.providers = []
 
         if provider not in cls.providers:
@@ -60,16 +60,16 @@ class Mixin(object):
 
     @classmethod
     def get_providers(cls) -> List[str]:
-        assert hasattr(cls, 'providers')
+        assert hasattr(cls, "providers")
         return cls.providers
 
     @classmethod
     def test_data_correctness(cls, provider, data_samples):
         for data in data_samples:
-            item = cls.query_data(provider=provider, ids=[data['id']], return_type='dict')
+            item = cls.query_data(provider=provider, ids=[data["id"]], return_type="dict")
             print(item)
             for k in data:
-                if k == 'timestamp':
+                if k == "timestamp":
                     assert is_same_time(item[0][k], data[k])
                 else:
                     assert item[0][k] == data[k]
@@ -77,57 +77,80 @@ class Mixin(object):
     @classmethod
     def get_one(cls, id, provider_index: int = 0, provider: str = None):
         from .api import get_one
+
         if not provider:
             provider = cls.providers[provider_index]
         return get_one(data_schema=cls, id=id, provider=provider)
 
     @classmethod
-    def query_data(cls,
-                   provider_index: int = 0,
-                   ids: List[str] = None,
-                   entity_ids: List[str] = None,
-                   entity_id: str = None,
-                   codes: List[str] = None,
-                   code: str = None,
-                   level: Union[IntervalLevel, str] = None,
-                   provider: str = None,
-                   columns: List = None,
-                   col_label: dict = None,
-                   return_type: str = 'df',
-                   start_timestamp: Union[pd.Timestamp, str] = None,
-                   end_timestamp: Union[pd.Timestamp, str] = None,
-                   filters: List = None,
-                   session: Session = None,
-                   order=None,
-                   limit: int = None,
-                   index: Union[str, list] = None,
-                   time_field: str = 'timestamp'):
+    def query_data(
+        cls,
+        provider_index: int = 0,
+        ids: List[str] = None,
+        entity_ids: List[str] = None,
+        entity_id: str = None,
+        codes: List[str] = None,
+        code: str = None,
+        level: Union[IntervalLevel, str] = None,
+        provider: str = None,
+        columns: List = None,
+        col_label: dict = None,
+        return_type: str = "df",
+        start_timestamp: Union[pd.Timestamp, str] = None,
+        end_timestamp: Union[pd.Timestamp, str] = None,
+        filters: List = None,
+        session: Session = None,
+        order=None,
+        limit: int = None,
+        index: Union[str, list] = None,
+        time_field: str = "timestamp",
+    ):
         from .api import get_data
+
         if not provider:
             provider = cls.providers[provider_index]
-        return get_data(data_schema=cls, ids=ids, entity_ids=entity_ids, entity_id=entity_id, codes=codes,
-                        code=code, level=level, provider=provider, columns=columns, col_label=col_label,
-                        return_type=return_type, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
-                        filters=filters, session=session, order=order, limit=limit, index=index, time_field=time_field)
+        return get_data(
+            data_schema=cls,
+            ids=ids,
+            entity_ids=entity_ids,
+            entity_id=entity_id,
+            codes=codes,
+            code=code,
+            level=level,
+            provider=provider,
+            columns=columns,
+            col_label=col_label,
+            return_type=return_type,
+            start_timestamp=start_timestamp,
+            end_timestamp=end_timestamp,
+            filters=filters,
+            session=session,
+            order=order,
+            limit=limit,
+            index=index,
+            time_field=time_field,
+        )
 
     @classmethod
-    def record_data(cls,
-                    provider_index: int = 0,
-                    provider: str = None,
-                    force_update=None,
-                    sleeping_time=None,
-                    exchanges=None,
-                    entity_ids=None,
-                    code=None,
-                    codes=None,
-                    real_time=None,
-                    fix_duplicate_way=None,
-                    start_timestamp=None,
-                    end_timestamp=None,
-                    one_day_trading_minutes=None,
-                    **kwargs):
+    def record_data(
+        cls,
+        provider_index: int = 0,
+        provider: str = None,
+        force_update=None,
+        sleeping_time=None,
+        exchanges=None,
+        entity_ids=None,
+        code=None,
+        codes=None,
+        real_time=None,
+        fix_duplicate_way=None,
+        start_timestamp=None,
+        end_timestamp=None,
+        one_day_trading_minutes=None,
+        **kwargs,
+    ):
         if cls.provider_map_recorder:
-            print(f'{cls.__name__} registered recorders:{cls.provider_map_recorder}')
+            print(f"{cls.__name__} registered recorders:{cls.provider_map_recorder}")
 
             if provider:
                 recorder_class = cls.provider_map_recorder[provider]
@@ -136,11 +159,15 @@ class Mixin(object):
 
             # get args for specific recorder class
             from zvt.contract.recorder import TimeSeriesDataRecorder
+
             if issubclass(recorder_class, TimeSeriesDataRecorder):
-                args = [item for item in inspect.getfullargspec(cls.record_data).args if
-                        item not in ('cls', 'provider_index', 'provider')]
+                args = [
+                    item
+                    for item in inspect.getfullargspec(cls.record_data).args
+                    if item not in ("cls", "provider_index", "provider")
+                ]
             else:
-                args = ['force_update', 'sleeping_time']
+                args = ["force_update", "sleeping_time"]
 
             # just fill the None arg to kw,so we could use the recorder_class default args
             kw = {}
@@ -151,22 +178,23 @@ class Mixin(object):
 
             # FixedCycleDataRecorder
             from zvt.contract.recorder import FixedCycleDataRecorder
+
             if issubclass(recorder_class, FixedCycleDataRecorder):
                 # contract:
                 # 1)use FixedCycleDataRecorder to record the data with IntervalLevel
                 # 2)the table of schema with IntervalLevel format is {entity}_{level}_[adjust_type]_{event}
                 table: str = cls.__tablename__
                 try:
-                    items = table.split('_')
+                    items = table.split("_")
                     if len(items) == 4:
                         adjust_type = items[2]
-                        kw['adjust_type'] = adjust_type
+                        kw["adjust_type"] = adjust_type
                     level = IntervalLevel(items[1])
                 except:
                     # for other schema not with normal format,but need to calculate size for remaining days
                     level = IntervalLevel.LEVEL_1DAY
 
-                kw['level'] = level
+                kw["level"] = level
 
                 # add other custom args
                 for k in kwargs:
@@ -180,7 +208,7 @@ class Mixin(object):
                 r.run()
                 return
         else:
-            print(f'no recorders for {cls.__name__}')
+            print(f"no recorders for {cls.__name__}")
 
 
 class NormalMixin(Mixin):
@@ -215,7 +243,7 @@ class TradableEntity(Entity):
         :param end_date:
         :return:
         """
-        return pd.date_range(start_date, end_date, freq='B')
+        return pd.date_range(start_date, end_date, freq="B")
 
     @classmethod
     def get_trading_intervals(cls):
@@ -224,7 +252,7 @@ class TradableEntity(Entity):
 
         :return:[(start,end)]
         """
-        return [('09:30', '11:30'), ('13:00', '15:00')]
+        return [("09:30", "11:30"), ("13:00", "15:00")]
 
     @classmethod
     def in_trading_time(cls, timestamp=None):
@@ -274,14 +302,18 @@ class TradableEntity(Entity):
     @classmethod
     def is_open_timestamp(cls, timestamp):
         timestamp = pd.Timestamp(timestamp)
-        return is_same_time(timestamp, date_and_time(the_date=timestamp.date(),
-                                                     the_time=cls.get_trading_intervals()[0][0]))
+        return is_same_time(
+            timestamp,
+            date_and_time(the_date=timestamp.date(), the_time=cls.get_trading_intervals()[0][0]),
+        )
 
     @classmethod
     def is_close_timestamp(cls, timestamp):
         timestamp = pd.Timestamp(timestamp)
-        return is_same_time(timestamp, date_and_time(the_date=timestamp.date(),
-                                                     the_time=cls.get_trading_intervals()[-1][1]))
+        return is_same_time(
+            timestamp,
+            date_and_time(the_date=timestamp.date(), the_time=cls.get_trading_intervals()[-1][1]),
+        )
 
     @classmethod
     def is_finished_kdata_timestamp(cls, timestamp: pd.Timestamp, level: IntervalLevel):
@@ -334,8 +366,14 @@ class NormalEntityMixin(TradableEntity):
 
 class Portfolio(TradableEntity):
     @classmethod
-    def get_stocks(cls,
-                   code=None, codes=None, ids=None, timestamp=now_pd_timestamp(), provider=None):
+    def get_stocks(
+        cls,
+        code=None,
+        codes=None,
+        ids=None,
+        timestamp=now_pd_timestamp(),
+        provider=None,
+    ):
         """
         the publishing policy of portfolio positions is different for different types,
         overwrite this function for get the holding stocks in specific date
@@ -348,7 +386,8 @@ class Portfolio(TradableEntity):
         :return:
         """
         from zvt.contract.api import get_schema_by_name
-        schema_str = f'{cls.__name__}Stock'
+
+        schema_str = f"{cls.__name__}Stock"
         portfolio_stock = get_schema_by_name(schema_str)
         return portfolio_stock.query_data(provider=provider, code=code, codes=codes, timestamp=timestamp, ids=ids)
 
@@ -415,4 +454,16 @@ class ActorMeetTradable(Mixin):
 
 
 # the __all__ is generated
-__all__ = ['Mixin', 'NormalMixin', 'Entity', 'TradableEntity', 'ActorEntity', 'NormalEntityMixin', 'Portfolio', 'PortfolioStock', 'PortfolioStockHistory', 'TradableMeetActor', 'ActorMeetTradable']
\ No newline at end of file
+__all__ = [
+    "Mixin",
+    "NormalMixin",
+    "Entity",
+    "TradableEntity",
+    "ActorEntity",
+    "NormalEntityMixin",
+    "Portfolio",
+    "PortfolioStock",
+    "PortfolioStockHistory",
+    "TradableMeetActor",
+    "ActorMeetTradable",
+]
