@@ -10,7 +10,7 @@ ZvtInfoBase = declarative_base()
 
 # 用于保存recorder的状态
 class RecorderState(ZvtInfoBase, Mixin):
-    __tablename__ = 'recoder_state'
+    __tablename__ = "recoder_state"
     # recorder名字
     recoder_name = Column(String(length=128))
 
@@ -20,7 +20,7 @@ class RecorderState(ZvtInfoBase, Mixin):
 
 # 用于保存tagger的状态
 class TaggerState(ZvtInfoBase, Mixin):
-    __tablename__ = 'tagger_state'
+    __tablename__ = "tagger_state"
     # tagger名字
     tagger_name = Column(String(length=128))
 
@@ -28,6 +28,6 @@ class TaggerState(ZvtInfoBase, Mixin):
     state = Column(Text())
 
 
-register_schema(providers=['zvt'], db_name='zvt_info', schema_base=ZvtInfoBase)
+register_schema(providers=["zvt"], db_name="zvt_info", schema_base=ZvtInfoBase)
 # the __all__ is generated
-__all__ = ['ZvtInfoBase', 'RecorderState', 'TaggerState']
\ No newline at end of file
+__all__ = ["ZvtInfoBase", "RecorderState", "TaggerState"]
