@@ -10,9 +10,9 @@ ActorMetaBase = declarative_base()
 
 # 参与者
 class ActorMeta(ActorMetaBase, ActorEntity):
-    __tablename__ = 'actor_meta'
+    __tablename__ = "actor_meta"
 
 
-register_schema(providers=['em'], db_name='actor_meta', schema_base=ActorMetaBase)
+register_schema(providers=["em"], db_name="actor_meta", schema_base=ActorMetaBase)
 # the __all__ is generated
-__all__ = ['ActorMeta']
\ No newline at end of file
+__all__ = ["ActorMeta"]
