@@ -9,14 +9,13 @@ StockhkMetaBase = declarative_base()
 
 
 # 港股
-@register_entity(entity_type='stockhk')
+@register_entity(entity_type="stockhk")
 class Stockhk(StockhkMetaBase, TradableEntity):
-    __tablename__ = 'stockhk'
+    __tablename__ = "stockhk"
     # 是否属于港股通
     south = Column(Boolean)
 
 
-register_schema(providers=['em'], db_name='stockhk_meta',
-                schema_base=StockhkMetaBase)
+register_schema(providers=["em"], db_name="stockhk_meta", schema_base=StockhkMetaBase)
 # the __all__ is generated
-__all__ = ['Stockhk']
+__all__ = ["Stockhk"]
