@@ -10,8 +10,9 @@ OverallBase = declarative_base()
 
 # 市场整体估值
 
+
 class StockSummary(OverallBase, Mixin):
-    __tablename__ = 'stock_summary'
+    __tablename__ = "stock_summary"
 
     provider = Column(String(length=32))
     code = Column(String(length=32))
@@ -28,8 +29,9 @@ class StockSummary(OverallBase, Mixin):
 
 # 融资融券概况
 
+
 class MarginTradingSummary(OverallBase, Mixin):
-    __tablename__ = 'margin_trading_summary'
+    __tablename__ = "margin_trading_summary"
     provider = Column(String(length=32))
     code = Column(String(length=32))
     name = Column(String(length=32))
@@ -50,8 +52,9 @@ class MarginTradingSummary(OverallBase, Mixin):
 
 # 北向/南向成交概况
 
+
 class CrossMarketSummary(OverallBase, Mixin):
-    __tablename__ = 'cross_market_summary'
+    __tablename__ = "cross_market_summary"
     provider = Column(String(length=32))
     code = Column(String(length=32))
     name = Column(String(length=32))
@@ -64,7 +67,7 @@ class CrossMarketSummary(OverallBase, Mixin):
     quota_daily_balance = Column(Float)
 
 
-register_schema(providers=['joinquant', 'exchange'], db_name='overall', schema_base=OverallBase, entity_type='stock')
+register_schema(providers=["joinquant", "exchange"], db_name="overall", schema_base=OverallBase, entity_type="stock")
 
 # the __all__ is generated
-__all__ = ['StockSummary', 'MarginTradingSummary', 'CrossMarketSummary']
\ No newline at end of file
+__all__ = ["StockSummary", "MarginTradingSummary", "CrossMarketSummary"]
