@@ -14,11 +14,11 @@ def drop_continue_duplicate(s: Union[pd.Series, pd.DataFrame], col=None):
 
 
 def is_filter_result_df(df: pd.DataFrame):
-    return pd_is_not_null(df) and 'filter_result' in df.columns
+    return pd_is_not_null(df) and "filter_result" in df.columns
 
 
 def is_score_result_df(df: pd.DataFrame):
-    return pd_is_not_null(df) and 'score_result' in df.columns
+    return pd_is_not_null(df) and "score_result" in df.columns
 
 
 def pd_is_not_null(df: Union[pd.DataFrame, pd.Series]):
@@ -37,14 +37,14 @@ def normalize_group_compute_result(group_result):
 
 def merge_filter_result(input_df: pd.DataFrame, filter_result: pd.Series):
     if is_filter_result_df(input_df):
-        input_df['filter_result'] = input_df['filter_result'] & filter_result
+        input_df["filter_result"] = input_df["filter_result"] & filter_result
     else:
-        input_df['filter_result'] = filter_result
+        input_df["filter_result"] = filter_result
 
     return input_df
 
 
-def index_df(df, index='timestamp', inplace=True, drop=False, time_field='timestamp'):
+def index_df(df, index="timestamp", inplace=True, drop=False, time_field="timestamp"):
     if time_field:
         df[time_field] = pd.to_datetime(df[time_field])
 
@@ -62,15 +62,15 @@ def index_df(df, index='timestamp', inplace=True, drop=False, time_field='timest
     return df
 
 
-def normal_index_df(df, category_field='entity_id', time_filed='timestamp', drop=True):
+def normal_index_df(df, category_field="entity_id", time_filed="timestamp", drop=True):
     index = [category_field, time_filed]
     if is_normal_df(df):
         return df
 
-    return index_df(df=df, index=index, drop=drop, time_field='timestamp')
+    return index_df(df=df, index=index, drop=drop, time_field="timestamp")
 
 
-def is_normal_df(df, category_field='entity_id', time_filed='timestamp'):
+def is_normal_df(df, category_field="entity_id", time_filed="timestamp"):
     if pd_is_not_null(df):
         names = df.index.names
 
@@ -109,5 +109,12 @@ def fill_with_same_index(df_list: List[pd.DataFrame]):
 
 
 # the __all__ is generated
-__all__ = ['pd_is_not_null', 'index_df', 'normal_index_df', 'is_normal_df', 'df_subset', 'fill_with_same_index',
-           'drop_continue_duplicate']
+__all__ = [
+    "pd_is_not_null",
+    "index_df",
+    "normal_index_df",
+    "is_normal_df",
+    "df_subset",
+    "fill_with_same_index",
+    "drop_continue_duplicate",
+]
